@@ -4,10 +4,9 @@
 #' @inheritParams doc_function
 #' @param activities \strong{\code{\link[tibble]{tibble}}} | Result of running decoupleR method with dorothea regulon prior knowledge.
 #' @param n_tfs \strong{\code{\link[base]{numeric}}} | Number of top regulons to consider for downstream analysis.
-#' @param plot_FeaturePlots \strong{\code{\link[base]{logical}}} | Compute output feature plots for each of the top regulons.
+#' @param plot_FeaturePlots \strong{\code{\link[base]{logical}}} | Compute output FeaturePlots for each of the top regulons.
 #' @param plot_Heatmaps \strong{\code{\link[base]{logical}}} | Compute output heatmap showcasing the average TF activity per regulon and group.by variable.
-#' @param plot_GeyserPlots \strong{\code{\link[base]{logical}}} | Compute output dotplot for each of the top regulons and group.by variable.
-#' @param geyser_color.by \strong{\code{\link[base]{character}}} | Additional variable to color the Geyser plots by, as the Y axis and the color scale are repeated. Has to be a continuous variable.
+#' @param plot_GeyserPlots \strong{\code{\link[base]{logical}}} | Compute output GeyserPlots for each of the top regulons and group.by variable.
 #' @param enforce_symmetry \strong{\code{\link[base]{logical}}} | Whether the geyser and feature plot has a symmetrical color scale.
 #' @param geyser_order_by_mean \strong{\code{\link[base]{logical}}} | Whether to order the X axis by the mean of the values.
 #' @param geyser_scale_type \strong{\code{\link[base]{character}}} | Type of scale to use. Either "continuous" or "categorical.
@@ -25,14 +24,13 @@ do_TFActivityPlot <- function(sample,
                               plot_FeaturePlots = FALSE,
                               plot_Heatmaps = TRUE,
                               plot_GeyserPlots = FALSE,
-                              geyser_color.by = NULL,
                               row_title = NULL,
                               column_title = NULL,
                               flip = FALSE,
                               cluster_cols = TRUE,
                               cluster_rows = TRUE,
                               row_names_rot = 0,
-                              column_names_rot = 90,
+                              column_names_rot = 45,
                               cell_size = 5,
                               pt.size = 1,
                               plot_cell_borders = TRUE,
@@ -56,7 +54,9 @@ do_TFActivityPlot <- function(sample,
                               geyser_order_by_mean = TRUE,
                               geyser_scale_type = "continuous",
                               viridis_color_map = "G",
-                              viridis_direction = 1){
+                              viridis_direction = 1,
+                              min.cutoff = NULL,
+                              max.cutoff = NULL){
   check_suggests(function_name = "do_TFActivityPlot")
   # Check if the sample provided is a Seurat object.
   check_Seurat(sample = sample)
@@ -87,7 +87,9 @@ do_TFActivityPlot <- function(sample,
                        "legend.framewidth" = legend.framewidth,
                        "legend.tickwidth" = legend.tickwidth,
                        "viridis_direction" = viridis_direction,
-                       "rotate_x_axis_labels" = rotate_x_axis_labels)
+                       "rotate_x_axis_labels" = rotate_x_axis_labels,
+                       "min.cutoff" = min.cutoff,
+                       "max.cutoff" = max.cutoff)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
   # Check character parameters.
   character_list <- list("group.by" = group.by,
@@ -198,7 +200,9 @@ do_TFActivityPlot <- function(sample,
                           legend.length = legend.length,
                           legend.width = legend.width,
                           viridis_color_map = viridis_color_map,
-                          viridis_direction = viridis_direction)
+                          viridis_direction = viridis_direction,
+                          min.cutoff = if (is.null(min.cutoff)) {NA} else {min.cutoff},
+                          max.cutoff = if (is.null(max.cutoff)) {NA} else {max.cutoff})
 
       list.features[[regulon]] <- p
     }
@@ -213,7 +217,6 @@ do_TFActivityPlot <- function(sample,
                          slot = "scale.data",
                          features = regulon,
                          group.by = group.by,
-                         color.by = geyser_color.by,
                          pt.size = pt.size,
                          border.size = border.size,
                          enforce_symmetry = enforce_symmetry,
@@ -232,10 +235,12 @@ do_TFActivityPlot <- function(sample,
                          legend.width = legend.width,
                          xlab = if (is.null(group.by)) {"Clusters"} else {group.by},
                          ylab = paste0(regulon, " activity"),
-                         legend.title = if (is.null(geyser_color.by)) {paste0(regulon, " activity")} else {geyser_color.by},
+                         legend.title = paste0(regulon, " activity"),
                          rotate_x_axis_labels = rotate_x_axis_labels,
                          viridis_color_map = viridis_color_map,
-                         viridis_direction = viridis_direction)
+                         viridis_direction = viridis_direction,
+                         min.cutoff = min.cutoff,
+                         max.cutoff = max.cutoff)
       list.geysers[[regulon]] <- p
     }
     list.out[["geyser_plots"]] <- list.geysers
@@ -264,6 +269,21 @@ do_TFActivityPlot <- function(sample,
         data <- top_acts_mat_wide
       }
 
+      range.data <- c(min(data), max(data))
+
+      if (!is.null(min.cutoff)){
+        assertthat::assert_that(min.cutoff >= range.data[1],
+                                msg = paste0("The value provided for min.cutoff (", min.cutoff, ") is lower than the minimum value in the enrichment matrix (", range.data[1], "). Please select another value."))
+        range.data <- c(min.cutoff, range.data[2])
+      }
+
+      if (!is.null(max.cutoff)){
+        assertthat::assert_that(max.cutoff <= range.data[2],
+                                msg = paste0("The value provided for max.cutoff (", max.cutoff, ") is lower than the maximum value in the enrichment matrix (", range.data[2], "). Please select another value."))
+        range.data <- c(range.data[1], max.cutoff)
+
+      }
+
       out <- heatmap_inner(data,
                            legend.title = "TF activity",
                            column_title = column_title,
@@ -274,6 +294,8 @@ do_TFActivityPlot <- function(sample,
                            row_names_rot = row_names_rot,
                            cell_size = cell_size,
                            na.value = na.value,
+                           data_range = "both",
+                           range.data = range.data,
                            legend.position = legend.position,
                            legend.length = heatmap.legend.length,
                            legend.width = heatmap.legend.width,
@@ -294,7 +316,33 @@ do_TFActivityPlot <- function(sample,
       split.values <- as.character(sort(unique(sample@meta.data %>% dplyr::pull(!!rlang::sym(split.by)))))
       list.heatmaps <- list()
       # Get the maximum range.
-      range <- max(abs(top_acts_mat_wide))
+      range.data <- range.data <- c(min(top_acts_mat_wide), max(top_acts_mat_wide))
+
+      if (!is.null(min.cutoff) & !is.null(max.cutoff)){
+        assertthat::assert_that(min.cutoff < max.cutoff,
+                                msg = paste0("The value provided for min.cutoff (", min.cutoff, ") has to be lower than the value provided to max.cutoff (", max.cutoff, "). Please select another value."))
+
+        assertthat::assert_that(max.cutoff > min.cutoff,
+                                msg = paste0("The value provided for max.cutoff (", max.cutoff, ") has to be higher than the value provided to min.cutoff (", min.cutoff, "). Please select another value."))
+
+        assertthat::assert_that(max.cutoff != min.cutoff,
+                                msg = paste0("The value provided for max.cutoff (", max.cutoff, ") can not be the same than the value provided to min.cutoff (", min.cutoff, "). Please select another value."))
+
+      }
+
+      if (!is.null(min.cutoff)){
+        assertthat::assert_that(min.cutoff >= range.data[1],
+                                msg = paste0("The value provided for min.cutoff (", min.cutoff, ") is lower than the minimum value in the enrichment matrix (", range.data[1], "). Please select another value."))
+        range.data <- c(min.cutoff, range.data[2])
+      }
+
+      if (!is.null(max.cutoff)){
+        assertthat::assert_that(max.cutoff <= range.data[2],
+                                msg = paste0("The value provided for max.cutoff (", max.cutoff, ") is lower than the maximum value in the enrichment matrix (", range.data[2], "). Please select another value."))
+        range.data <- c(range.data[1], max.cutoff)
+
+      }
+
       for (split.value in split.values){
         suppressMessages({
           data <- sample@assays$dorothea@scale.data[tfs, ] %>%
@@ -339,6 +387,8 @@ do_TFActivityPlot <- function(sample,
                              row_names_rot = row_names_rot,
                              cell_size = cell_size,
                              na.value = na.value,
+                             data_range = "both",
+                             range.data = range.data,
                              legend.position = legend.position,
                              legend.length = heatmap.legend.length,
                              legend.width = heatmap.legend.width,
