@@ -1,5 +1,33 @@
 if (isFALSE(dep_check[["do_BarPlot"]])){
+
+  testthat::test_that("do_BarPlot: CRAN essential tests", {
+    sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
+
+    p <- SCpubr::do_BarPlot(sample = sample,
+                            group.by = "seurat_clusters",
+                            position = "stack")
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_BarPlot(sample = sample,
+                            group.by = "seurat_clusters",
+                            position = "fill")
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_BarPlot(sample = sample,
+                            group.by = "seurat_clusters",
+                            split.by = "orig.ident",
+                            position = "stack")
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_BarPlot(sample = sample,
+                            group.by = "seurat_clusters",
+                            split.by = "orig.ident",
+                            position = "fill")
+    testthat::expect_type(p, "list")
+  })
+
   testthat::test_that("do_BarPlot: PASS - one variable - stack", {
+    testthat::skip_on_cran()
 
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "seurat_clusters",
@@ -8,6 +36,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - one variable - fill", {
+    testthat::skip_on_cran()
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "seurat_clusters",
                             position = "fill")
@@ -15,6 +44,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - one variable - remove guides", {
+    testthat::skip_on_cran()
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "seurat_clusters",
                             position = "stack",
@@ -23,6 +53,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - one variable - fill - flip", {
+    testthat::skip_on_cran()
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = NULL,
@@ -32,6 +63,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - two variables - fill - flip", {
+    testthat::skip_on_cran()
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "seurat_clusters",
@@ -42,6 +74,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - two variables - stack - flip", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -54,6 +87,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - two variables - stack - flip - ordered", {
+    testthat::skip_on_cran()
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
     p <- SCpubr::do_BarPlot(sample = sample,
@@ -68,6 +102,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
 
 
   testthat::test_that("do_BarPlot: FAIL - wrong position", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     testthat::expect_error(SCpubr::do_BarPlot(sample = sample,
@@ -76,6 +111,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: FAIL - wrong font.type", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     testthat::expect_error(SCpubr::do_BarPlot(sample = sample,
@@ -84,6 +120,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: FAIL - column not a factor or character", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     testthat::expect_error(SCpubr::do_BarPlot(sample = sample,
@@ -91,15 +128,17 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - rotate x labels", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "orig.ident",
-                            rotate_x_axis_labels  = TRUE)
+                            rotate_x_axis_labels  = 0)
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_BarPlot: PASS - rotate x labels", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     sample$seurat.clusters.factor <- factor(sample$seurat_clusters)
@@ -109,6 +148,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - rotate x labels with group.by", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     sample$seurat.clusters.factor <- factor(sample$seurat_clusters)
@@ -120,6 +160,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
 
 
   testthat::test_that("do_BarPlot: PASS - colors.use and group.by", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     sample$seurat.clusters.factor <- factor(sample$seurat_clusters)
@@ -142,6 +183,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - colors.use ", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     sample$seurat.clusters.factor <- factor(sample$seurat_clusters)
@@ -164,6 +206,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
 
 
   testthat::test_that("do_BarPlot: FAIL - order by not in group.by", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     testthat::expect_error(SCpubr::do_BarPlot(sample = sample,
@@ -173,16 +216,18 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
 
 
   testthat::test_that("do_BarPlot: PASS - one variable - rotate x labels", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     p <- SCpubr::do_BarPlot(sample = sample,
                             group.by = "orig.ident",
                             position = "stack",
-                            rotate_x_axis_labels = TRUE)
+                            rotate_x_axis_labels = 0)
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_BarPlot: PASS - one variable - xlab, ylab and title", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     p <- SCpubr::do_BarPlot(sample = sample,
@@ -197,6 +242,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
   })
 
   testthat::test_that("do_BarPlot: PASS - one variable - no legend", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     p <- SCpubr::do_BarPlot(sample = sample,
@@ -208,6 +254,7 @@ if (isFALSE(dep_check[["do_BarPlot"]])){
 
 
   testthat::test_that("do_BarPlot: PASS - group.by factor", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
     sample$factor_seurat_clusters <- factor(sample$seurat_clusters)
