@@ -1,6 +1,21 @@
 if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
-  testthat::test_that("do_BeeSwarmPlot: PASS - categorical variable dimred component", {
 
+  testthat::test_that("do_BeeSwarmPlot: CRAN essentials", {
+    p <- SCpubr::do_BeeSwarmPlot(sample = sample,
+                                 feature_to_rank = "PC_1",
+                                 group.by = "seurat_clusters",
+                                 continuous_feature = FALSE)
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_BeeSwarmPlot(sample = sample,
+                                 feature_to_rank = "PC_1",
+                                 group.by = "seurat_clusters",
+                                 continuous_feature = TRUE)
+    testthat::expect_type(p, "list")
+  })
+
+  testthat::test_that("do_BeeSwarmPlot: PASS - categorical variable dimred component", {
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -9,6 +24,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - cell_borders", {
+    testthat::skip_on_cran()
 
     p <- SCpubr::do_BeeSwarmPlot(sample = sample, feature_to_rank = "EPC1", group.by = "seurat_clusters", plot_cell_borders = TRUE)
     testthat::expect_type(p, "list")
@@ -17,6 +33,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - categorical variable gene", {
+    testthat::skip_on_cran()
 
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "EPC1",
@@ -26,6 +43,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - legend position = right", {
+    testthat::skip_on_cran()
 
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "EPC1",
@@ -36,7 +54,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - categorical variable metadata", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "nCount_RNA",
                                  group.by = "seurat_clusters",
@@ -45,7 +63,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - continuous variable", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -54,7 +72,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - continuous variable legend normal", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -64,7 +82,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - continuous variable legend colorbar", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -74,7 +92,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - continuous variable legend colorsteps", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -84,7 +102,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: FAIL - wrong legend type", {
-
+    testthat::skip_on_cran()
     testthat::expect_error(SCpubr::do_BeeSwarmPlot(sample = sample,
                                                    feature_to_rank = "PC_1",
                                                    group.by = "seurat_clusters",
@@ -93,7 +111,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: FAIL - more than one feature", {
-
+    testthat::skip_on_cran()
     testthat::expect_error(SCpubr::do_BeeSwarmPlot(sample = sample,
                                                    feature_to_rank = c("PC_1", "PC_2"),
                                                    group.by = "seurat_clusters",
@@ -101,7 +119,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: FAIL - wrong legend position", {
-
+    testthat::skip_on_cran()
     testthat::expect_error(SCpubr::do_BeeSwarmPlot(sample = sample,
                                                    feature_to_rank = "PC_1",
                                                    group.by = "seurat_clusters",
@@ -110,7 +128,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: FAIL - wrong font.type", {
-
+    testthat::skip_on_cran()
     testthat::expect_error(SCpubr::do_BeeSwarmPlot(sample = sample,
                                                    feature_to_rank = "PC_1",
                                                    group.by = "seurat_clusters",
@@ -119,7 +137,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - continuous variable viridis scale", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -129,7 +147,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - continuous variable legend position = top", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -139,7 +157,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: FAIL - feature not found", {
-
+    testthat::skip_on_cran()
     testthat::expect_error(SCpubr::do_BeeSwarmPlot(sample = sample,
                                                    feature_to_rank = "not_found",
                                                    group.by = "seurat_clusters",
@@ -148,7 +166,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - raster", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -157,7 +175,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - colors.use", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -174,7 +192,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - remove x axis", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -183,7 +201,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - remove y axis", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
@@ -192,7 +210,7 @@ if (isFALSE(dep_check[["do_BeeSwarmPlot"]])){
   })
 
   testthat::test_that("do_BeeSwarmPlot: PASS - flip", {
-
+    testthat::skip_on_cran()
     p <- SCpubr::do_BeeSwarmPlot(sample = sample,
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
