@@ -1,6 +1,43 @@
 if(isFALSE(dep_check[["do_RidgePlot"]])){
-  testthat::test_that("do_RidgePlot: PASS - default", {
 
+  testthat::test_that("do_RidgePlot: CRAN essentials", {
+
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA")
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = TRUE,
+                              viridis_direction = 1)
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nFeature_RNA",
+                              continuous_scale = TRUE,
+                              compute_quantiles = TRUE,
+                              compute_distribution_tails = TRUE)
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = TRUE,
+                              compute_quantiles = TRUE,
+                              compute_distribution_tails = TRUE,
+                              prob_tails = 0.4)
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nFeature_RNA",
+                              continuous_scale = TRUE,
+                              compute_quantiles = TRUE,
+                              color_by_probabilities = TRUE)
+    testthat::expect_type(p, "list")
+
+  })
+
+  testthat::test_that("do_RidgePlot: PASS - default", {
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -33,7 +70,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
   })
 
   testthat::test_that("do_RidgePlot: PASS - plot.grid", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -49,7 +86,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
 
 
   testthat::test_that("do_RidgePlot: PASS - split.by", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -59,7 +96,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
   })
 
   testthat::test_that("do_RidgePlot: PASS - continuous scale", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -76,7 +113,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
   })
 
   testthat::test_that("do_RidgePlot: PASS - group.by", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -86,7 +123,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
   })
 
   testthat::test_that("do_RidgePlot: PASS - quantiles", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -106,7 +143,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
   })
 
   testthat::test_that("do_RidgePlot: PASS - distribution tails", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
@@ -126,7 +163,7 @@ if(isFALSE(dep_check[["do_RidgePlot"]])){
   })
 
   testthat::test_that("do_RidgePlot: PASS - distribution tails", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_RidgePlot(sample = sample,
